@@ -16,6 +16,8 @@ lock = False
 debugFlags = None
 httpServer = None
 wsServer = None
+inferior_run_times = {}
+step_time = False
 
 def init():
     global lock
@@ -27,12 +29,16 @@ def init():
     global httpServer
     global httpServer
     global wsServer
+    global inferior_run_times
+    global step_time
 
 def access(function):
     global lock
     global debugFlags
     global httpServer
     global wsServer
+    global inferior_run_times
+    global step_time
 
     lock.acquire()
     function()
